#[non_exhaustive]pub struct CodeCaptureConfigurationBuilder { /* private fields */ }Expand description
A builder for CodeCaptureConfiguration.
Implementations
Sourceimpl CodeCaptureConfigurationBuilder
impl CodeCaptureConfigurationBuilder
Sourcepub fn capture_arguments(self, input: impl Into<String>) -> Self
pub fn capture_arguments(self, input: impl Into<String>) -> Self
Appends an item to capture_arguments.
To override the contents of this collection use set_capture_arguments.
The function arguments to capture. Omit to capture defaults, use an empty list to capture none, use \["*"\] to capture all arguments, or specify argument names to capture selectively (up to 10 entries).
Sourcepub fn set_capture_arguments(self, input: Option<Vec<String>>) -> Self
pub fn set_capture_arguments(self, input: Option<Vec<String>>) -> Self
The function arguments to capture. Omit to capture defaults, use an empty list to capture none, use \["*"\] to capture all arguments, or specify argument names to capture selectively (up to 10 entries).
Sourcepub fn get_capture_arguments(&self) -> &Option<Vec<String>>
pub fn get_capture_arguments(&self) -> &Option<Vec<String>>
The function arguments to capture. Omit to capture defaults, use an empty list to capture none, use \["*"\] to capture all arguments, or specify argument names to capture selectively (up to 10 entries).
Sourcepub fn capture_return(self, input: bool) -> Self
pub fn capture_return(self, input: bool) -> Self
Whether to capture the return value. Defaults to false.
Sourcepub fn set_capture_return(self, input: Option<bool>) -> Self
pub fn set_capture_return(self, input: Option<bool>) -> Self
Whether to capture the return value. Defaults to false.
Sourcepub fn get_capture_return(&self) -> &Option<bool>
pub fn get_capture_return(&self) -> &Option<bool>
Whether to capture the return value. Defaults to false.
Sourcepub fn capture_stack_trace(self, input: bool) -> Self
pub fn capture_stack_trace(self, input: bool) -> Self
Whether to capture a stack trace when the instrumentation point is hit. Defaults to true.
Sourcepub fn set_capture_stack_trace(self, input: Option<bool>) -> Self
pub fn set_capture_stack_trace(self, input: Option<bool>) -> Self
Whether to capture a stack trace when the instrumentation point is hit. Defaults to true.
Sourcepub fn get_capture_stack_trace(&self) -> &Option<bool>
pub fn get_capture_stack_trace(&self) -> &Option<bool>
Whether to capture a stack trace when the instrumentation point is hit. Defaults to true.
Sourcepub fn capture_locals(self, input: impl Into<String>) -> Self
pub fn capture_locals(self, input: impl Into<String>) -> Self
Appends an item to capture_locals.
To override the contents of this collection use set_capture_locals.
The local variables to capture by name. Omit or pass an empty list to capture none. You can specify up to 20 names.
Sourcepub fn set_capture_locals(self, input: Option<Vec<String>>) -> Self
pub fn set_capture_locals(self, input: Option<Vec<String>>) -> Self
The local variables to capture by name. Omit or pass an empty list to capture none. You can specify up to 20 names.
Sourcepub fn get_capture_locals(&self) -> &Option<Vec<String>>
pub fn get_capture_locals(&self) -> &Option<Vec<String>>
The local variables to capture by name. Omit or pass an empty list to capture none. You can specify up to 20 names.
Sourcepub fn capture_limits(self, input: CaptureLimitsConfig) -> Self
pub fn capture_limits(self, input: CaptureLimitsConfig) -> Self
Safety limits that bound what is captured, including hit counts, string length, collection depth, and stack trace size.
This field is required.Sourcepub fn set_capture_limits(self, input: Option<CaptureLimitsConfig>) -> Self
pub fn set_capture_limits(self, input: Option<CaptureLimitsConfig>) -> Self
Safety limits that bound what is captured, including hit counts, string length, collection depth, and stack trace size.
Sourcepub fn get_capture_limits(&self) -> &Option<CaptureLimitsConfig>
pub fn get_capture_limits(&self) -> &Option<CaptureLimitsConfig>
Safety limits that bound what is captured, including hit counts, string length, collection depth, and stack trace size.
Sourcepub fn build(self) -> CodeCaptureConfiguration
pub fn build(self) -> CodeCaptureConfiguration
Consumes the builder and constructs a CodeCaptureConfiguration.