#[non_exhaustive]pub enum CaptureConfiguration {
CodeCapture(CodeCaptureConfiguration),
#[non_exhaustive] Unknown,
}Expand description
A union that defines what data to capture when the instrumentation point is hit. Specify CodeCapture for code-level capture settings.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CodeCapture(CodeCaptureConfiguration)
Capture settings for code-level instrumentation, including arguments, return values, stack traces, local variables, and safety limits.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl CaptureConfiguration
impl CaptureConfiguration
Sourcepub fn as_code_capture(&self) -> Result<&CodeCaptureConfiguration, &Self>
pub fn as_code_capture(&self) -> Result<&CodeCaptureConfiguration, &Self>
Tries to convert the enum instance into CodeCapture, extracting the inner CodeCaptureConfiguration.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_code_capture(&self) -> bool
pub fn is_code_capture(&self) -> bool
Returns true if this is a CodeCapture.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.