#[non_exhaustive]pub struct CodeCaptureConfiguration {
pub capture_arguments: Option<Vec<String>>,
pub capture_return: Option<bool>,
pub capture_stack_trace: Option<bool>,
pub capture_locals: Option<Vec<String>>,
pub capture_limits: Option<CaptureLimitsConfig>,
}Expand description
Defines what data to capture for code-level instrumentation, including arguments, return values, stack traces, local variables, and safety limits.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.capture_arguments: Option<Vec<String>>The function arguments to capture. Omit to capture defaults, use an empty list to capture none, use \["*"\] to capture all arguments, or specify argument names to capture selectively (up to 10 entries).
capture_return: Option<bool>Whether to capture the return value. Defaults to false.
capture_stack_trace: Option<bool>Whether to capture a stack trace when the instrumentation point is hit. Defaults to true.
capture_locals: Option<Vec<String>>The local variables to capture by name. Omit or pass an empty list to capture none. You can specify up to 20 names.
capture_limits: Option<CaptureLimitsConfig>Safety limits that bound what is captured, including hit counts, string length, collection depth, and stack trace size.
Implementations
Sourceimpl CodeCaptureConfiguration
impl CodeCaptureConfiguration
Sourcepub fn capture_arguments(&self) -> &[String]
pub fn capture_arguments(&self) -> &[String]
The function arguments to capture. Omit to capture defaults, use an empty list to capture none, use \["*"\] to capture all arguments, or specify argument names to capture selectively (up to 10 entries).
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .capture_arguments.is_none().
Sourcepub fn capture_return(&self) -> Option<bool>
pub fn capture_return(&self) -> Option<bool>
Whether to capture the return value. Defaults to false.
Sourcepub fn capture_stack_trace(&self) -> Option<bool>
pub fn capture_stack_trace(&self) -> Option<bool>
Whether to capture a stack trace when the instrumentation point is hit. Defaults to true.
Sourcepub fn capture_locals(&self) -> &[String]
pub fn capture_locals(&self) -> &[String]
The local variables to capture by name. Omit or pass an empty list to capture none. You can specify up to 20 names.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .capture_locals.is_none().
Sourcepub fn capture_limits(&self) -> Option<&CaptureLimitsConfig>
pub fn capture_limits(&self) -> Option<&CaptureLimitsConfig>
Safety limits that bound what is captured, including hit counts, string length, collection depth, and stack trace size.
Sourceimpl CodeCaptureConfiguration
impl CodeCaptureConfiguration
Sourcepub fn builder() -> CodeCaptureConfigurationBuilder
pub fn builder() -> CodeCaptureConfigurationBuilder
Creates a new builder-style object to manufacture CodeCaptureConfiguration.