CodeLocation

Struct CodeLocation 

#[non_exhaustive]
pub struct CodeLocation { pub language: ProgrammingLanguage, pub code_unit: Option<String>, pub class_name: Option<String>, pub method_name: Option<String>, pub file_path: String, pub line_number: Option<i32>, }
Identifies a code location to instrument, including the programming language, code unit, class, method, file path, and optional line number.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
language: ProgrammingLanguage

The programming language for this instrumentation point, such as Java, Python, or JavaScript.

code_unit: Option<String>

The package, module, or namespace that contains the target code, for example com.amazon.payment or payment_service.

class_name: Option<String>

The class or type name that contains the method. This is required for Java and optional for Python module-level functions.

method_name: Option<String>

The method or function name to instrument, such as validateCreditCard or __init__.

file_path: String

The source file path relative to the project or source root, such as src/payment/PaymentProcessor.java or src/payment/PaymentProcessor.py.

line_number: Option<i32>

The line number to instrument. Provide this to disambiguate overloaded methods and to target a specific line when needed.

Implementations

Source

impl CodeLocation

pub fn language(&self) -> &ProgrammingLanguage

The programming language for this instrumentation point, such as Java, Python, or JavaScript.

pub fn code_unit(&self) -> Option<&str>

The package, module, or namespace that contains the target code, for example com.amazon.payment or payment_service.

pub fn class_name(&self) -> Option<&str>

The class or type name that contains the method. This is required for Java and optional for Python module-level functions.

pub fn method_name(&self) -> Option<&str>

The method or function name to instrument, such as validateCreditCard or __init__.

pub fn file_path(&self) -> &str

The source file path relative to the project or source root, such as src/payment/PaymentProcessor.java or src/payment/PaymentProcessor.py.

pub fn line_number(&self) -> Option<i32>

The line number to instrument. Provide this to disambiguate overloaded methods and to target a specific line when needed.

Source

impl CodeLocation

pub fn builder() -> CodeLocationBuilder

Creates a new builder-style object to manufacture CodeLocation.