#[non_exhaustive]pub struct UnprocessedStatusEvent {
pub instrumentation_type: InstrumentationType,
pub signal_type: DynamicInstrumentationSignalType,
pub location_hash: String,
pub status: InstrumentationConfigurationStatus,
pub time: DateTime,
pub failed_reason: UnprocessedStatusEventFailureReason,
}Expand description
A status event that could not be processed by the service.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.instrumentation_type: InstrumentationTypeThe type of instrumentation configuration for the unprocessed status event.
signal_type: DynamicInstrumentationSignalTypeThe telemetry signal type for the unprocessed status event.
location_hash: StringThe stable hash of the instrumentation location for the unprocessed event.
status: InstrumentationConfigurationStatusThe status that failed to be processed.
time: DateTimeThe timestamp of the status event that failed to be processed.
failed_reason: UnprocessedStatusEventFailureReasonThe reason why this status event could not be processed, such as throttling or validation errors.
Implementations
Sourceimpl UnprocessedStatusEvent
impl UnprocessedStatusEvent
Sourcepub fn instrumentation_type(&self) -> &InstrumentationType
pub fn instrumentation_type(&self) -> &InstrumentationType
The type of instrumentation configuration for the unprocessed status event.
Sourcepub fn signal_type(&self) -> &DynamicInstrumentationSignalType
pub fn signal_type(&self) -> &DynamicInstrumentationSignalType
The telemetry signal type for the unprocessed status event.
Sourcepub fn location_hash(&self) -> &str
pub fn location_hash(&self) -> &str
The stable hash of the instrumentation location for the unprocessed event.
Sourcepub fn status(&self) -> &InstrumentationConfigurationStatus
pub fn status(&self) -> &InstrumentationConfigurationStatus
The status that failed to be processed.
Sourcepub fn failed_reason(&self) -> &UnprocessedStatusEventFailureReason
pub fn failed_reason(&self) -> &UnprocessedStatusEventFailureReason
The reason why this status event could not be processed, such as throttling or validation errors.
Sourceimpl UnprocessedStatusEvent
impl UnprocessedStatusEvent
Sourcepub fn builder() -> UnprocessedStatusEventBuilder
pub fn builder() -> UnprocessedStatusEventBuilder
Creates a new builder-style object to manufacture UnprocessedStatusEvent.